@@ -25,7 +25,8 @@ use CGI;
 use HTTP::Status qw(:constants :is);
 use HTTP::Headers;
 
-our $VERSION = q[476.4.2];
+our $VERSION = q[477.1.2];
+
 our $CRUD    = { # these map HTTP verbs to $action
 		POST    => 'create',
 		GET     => 'read',
@@ -315,7 +316,7 @@ sub process_request { ## no critic (Subroutines::ProhibitExcessComplexity)
     }
   }
 
-  if($aspect !~ /^(?:create|read|update|delete|add|list|edit)/smx) {
+  if($aspect !~ /^(?:create|read|update|delete|add|list|edit|options)/smx) {
     my $action_extended = $action;
     if(!$id) {
       $action_extended = {
@@ -326,10 +327,10 @@ sub process_request { ## no critic (Subroutines::ProhibitExcessComplexity)
     $aspect = $action_extended . ($aspect?"_$aspect":q[]);
   }
 
-  if($method eq 'OPTIONS') {
-    $action = 'options';
-    $aspect = 'options';
-  }
+#  if($method eq 'OPTIONS') {
+#    $action = 'options';
+#    $aspect = 'options';
+#  }
 
   #########
   # sanity checks
@@ -519,9 +520,9 @@ sub handler {
   $headers->header('Content-Type', $content_type);
 
   if($decor) {
-    if($content_type =~ /text/smx && $charset =~ /utf-?8/smix) {
-      binmode STDOUT, q[:encoding(UTF-8)]; # is this useful? If so, should it be less conditional?
-    }
+#    if($content_type =~ /text/smx && $charset =~ /utf-?8/smix) {
+#      binmode STDOUT, q[:encoding(UTF-8)]; # is this useful? If so, should it be less conditional?
+#    }
 
     #########
     # decorated header
